<?php
namespace Models;

// Модель строк чека
class Receiptlines extends \DB\SQL\Mapper {
	public $db, $f3;

	public function __construct($db, $f3) {
		parent::__construct($db, 'receiptlines' ); // подключаемся к таблице строк чека
		$this->db=$db;
		$this->f3=$f3;
	}

	// Выбираем строки из базы
	function select_lines($query) {
		$lines=array();
		$this->load($query);
		if(!$this->dry()) {
			do {
				$lines[]=$this->cast();
			}
			while($this->skip());
		}
		$this->reset();
		return $lines;
	}

	// Добавляем строку в чек
	function add_line($line, $count=1) {
		$line['count']=$count;
		$lines=$this->f3->get('SESSION.receiptlines');
		$lines[]=$line;
		$l=array_slice($lines, -1, 1, true);
		$id=key($l);
		$this->f3->set('SESSION.receiptlines', $lines);
		return array(
			'success'=>true,
			'txt'=>'save_successful',
			'reload'=>'.receiptlines',
			'id'=>$id,
			'close_all_window'=>true
		);
	}

	// Меняем строку в чеке
	function change_line($line_id, $count, $price) {
		$lines=$this->f3->get('SESSION.receiptlines');
		if(!isset($lines[$line_id])) {
			return array(
				'success'=>false,
				'txt'=>'not_found'
			);
		}
		if($count) {
			$lines[$line_id]['count']=$count;
		}
		if($price) {
			$lines[$line_id]['price']=$price;
		}
		$this->f3->set('SESSION.receiptlines', $lines);
		return array(
			'success'=>true,
			'txt'=>'save_successful',
			'reload'=>'.receiptlines',
			'id'=>$line_id,
			'close_all_window'=>true
		);
	}

	// Удаляем строку из чека
	function delete_line($line_id) {
		if($line_id=='all') {
			$fr=new \Models\Fr($this->db, $this->f3);
			$fr->reset_ticket();
			$this->f3->clear('SESSION.receiptlines');
			$this->f3->clear('COOKIE.discount');
		}
		else {
			$lines=$this->f3->get('SESSION.receiptlines');
			if(!isset($lines[$line_id])) {
				return array(
					'success'=>false,
					'txt'=>'not_found'
				);
			}
			unset($lines[$line_id]);
			$this->f3->set('SESSION.receiptlines', $lines);
		}

		return array(
			'success'=>true,
			'txt'=>'save_successful',
			'reload'=>'.receiptlines',
			'close_all_window'=>true
		);
	}

	// Узнаем сумму строк
	function get_sum($lines, $discount=0) {
		$sum=0;
		if($lines) {
			foreach ($lines as $l) {
				$s=($l['price']+($l['price']*(($l['vat']/100)*max(0, $l['vat_type']))));
				if($l['discount']) {
					$s-=$s*($l['discount']/100);
				}
				$sum+=$s*$l['count'];
			}
		}
		if($discount) {
			$sum-=$sum*($discount/100);
		}
		return $sum;
	}

	// Сохраняем строки в базе данных
	function save_lines($receipt_id, $lines, $discount=0) {
		if(!$lines) {
			return array(
				'success'=>false,
				'txt'=>'not_enough_data'
			);
		}

		// Формируем данные для сохранения
		foreach ($lines as $l) {
			$this->reset();
			$d=$discount;
			if($l['discount']) {
				$d=$l['discount'];
			}
			$receiptlines=array(
				'receipt_id'=>$receipt_id,
				'product_id'=>$l['id'],
				'product_title'=>$l['short_title'],
				'price'=>$l['price'],
				'vat'=>$l['vat'],
				'vat_type'=>$l['vat_type'],
				'count'=>$l['count'],
				'discount'=>$d
			);
			$this->copyFrom($receiptlines);
			$this->save();
			$res=$this->get('_id');
			if(!$res) {
				return array(
					'success'=>false,
					'txt'=>'db_error'
				);
			}
		}
		$this->reset();
		return array(
			'success'=>true,
			'txt'=>'save_successful'
		);
	}
}